@@ -11,8 +11,6 @@ from haystack.views import SearchView
 
 from django.conf import settings
 
-from .forms import CommentForm
-
 context_dict = {
 	'header_title':'Welcome to Django Blog App',
 	'header':'bootlog/head.html',
@@ -25,9 +23,6 @@ context_dict = {
 	'mid_column':"bootlog/mid_column.html",
 	'side_panel':'bootlog/side_panel.html',
 	'base_page': 'bootlog/base.html',
-	'footer_caption': 'This site is powered by Django, Bootstrap & Glyphicons.',
-	'post_single':'bootlog/post.html',
-	'url_addr': '127.0.0.1:8000/b/',
 }
 
 def write_context_dict(keys, c_d, s_c_d):
@@ -85,11 +80,12 @@ def home(request):
 		posts = Post.objects.all()
 	else:
 		posts = Post.objects.filter(category__category=request.GET.get('category'))
-	entries = posts.order_by('-id')
+	entries = posts.order_by('-pub_date')
 	context_dict['entries'] = get_paginated_view(request,entries,posts_per_page)
 	context_dict['category_split'] = get_category_post_count()
 	return render(request,context_dict['base_page'],context_dict)
 
+
 class BSearchView(SearchView):
 	def create_response(self):
 		"""
@@ -111,32 +107,4 @@ class BSearchView(SearchView):
 		if self.results and hasattr(self.results, 'query') and self.results.query.backend.include_spelling:
 			context['suggestion'] = self.form.get_suggestion()
 		
-		return render_to_response(self.template, context, context_instance = self.context_class(self.request))
-
-def perma_post(request,blog_pk,post_pk):
-	entry = Post.objects.filter(blog=blog_pk,pk=post_pk)
-	context_dict['entries'] = entry
-	return render(request,context_dict['base_page'],context_dict)
-
-
-def view_404(request):
-	context_dict['mid_column'] = 'bootlog/404.html'
-	context_dict['msg']='Why a 404!!!'
-	context_dict['category_split'] = get_category_post_count()
-	return render(request,context_dict['base_page'],context_dict)
-
-def comment_view(request):
-	if request.method == 'POST':
-
-		form = CommentForm(request.POST)
-		if form.is_valid():
-
-			return HttpResponse("%s" %(form.cleaned_data))
-		else:
-			return HttpResponse(":-/")
-	elif request.method == "GET":
-		form = CommentForm()
-		#return render(request, 'bootlog/form.html',{'form':form})
-		context_dict['form'] = form
-		
-		return render(request, 'bootlog/comment_form.html',context_dict)
\ No newline at end of file
+		return render_to_response(self.template, context, context_instance = self.context_class(self.request))
\ No newline at end of file
